There are even more chatterbots you can talk to. Try looking at the [list on wikipedia](https://en.wikipedia.org/wiki/List_of_chatterbots), or doing a google search for chatterbots. Each chatterbot on this list has its own wikipedia page. You should be able to find the chatterbots by either an internet search, or looking at the references of the wikipedia pages. Some of these will have rules that were determined by programmers, and others will have rules that were learnt from humans.

If you have a device that runs Apple iOS (for example an iPhone), have a look at the [Siri](https://en.wikipedia.org/wiki/Siri_%28software%29) chatterbot in the device’s help system. Siri is an example of a chatterbot that has the job of *helping* a human, unlike most chatterbots which simply have the purpose of web entertainment.  It also has voice recognition, so you can talk to it rather than just typing to it.

### The Turing Test

{panel type="teacher-note" summary="TED video introducing the Turing Test"}

There is a TED video that gives an overview of the Turing Test on YouTube

{video url="https://www.youtube.com/watch?v=3wLqsRLvV-c"}

{panel end}